//
// Copyright 2021 Vulcanize, Inc.
//

import { Entity, PrimaryColumn, Column, Index } from 'typeorm';
import { PairType } from '../types';
import { decimalTransformer, bigintTransformer } from '@cerc-io/util';
import { Decimal } from 'decimal.js';

@Entity()
@Index(['blockNumber'])
export class Factory {
  @PrimaryColumn('varchar')
    id!: string;

  @PrimaryColumn('varchar', { length: 66 })
    blockHash!: string;

  @Column('integer')
    blockNumber!: number;

  @Column({ type: 'enum', enum: PairType })
    type!: PairType;

  @Column('numeric', { transformer: decimalTransformer })
    volumeUSD!: Decimal;

  @Column('numeric', { transformer: decimalTransformer })
    volumeNative!: Decimal;

  @Column('numeric', { transformer: decimalTransformer })
    liquidityUSD!: Decimal;

  @Column('numeric', { transformer: decimalTransformer })
    liquidityNative!: Decimal;

  @Column('numeric', { transformer: decimalTransformer })
    feesUSD!: Decimal;

  @Column('numeric', { transformer: decimalTransformer })
    feesNative!: Decimal;

  @Column('numeric', { transformer: bigintTransformer })
    pairCount!: bigint;

  @Column('numeric', { transformer: bigintTransformer })
    transactionCount!: bigint;

  @Column('numeric', { transformer: bigintTransformer })
    tokenCount!: bigint;

  @Column('numeric', { transformer: bigintTransformer })
    userCount!: bigint;

  @Column('boolean', { default: false })
    isPruned!: boolean;

  @Column('boolean', { default: false })
    isRemoved!: boolean;
}
